@@ -20,6 +20,7 @@ class BlockBuilder:
         Define a fixed batchsize for the input.
 
     """
+
     def __init__(self, defaults=None, verbose=False, input_opts=None, **kwargs):
         """
         Set dict with default values for the layers of the model.
@@ -109,7 +110,7 @@ class BlockBuilder:
         return block(**filled)(layer)
 
     def _with_defaults(self, config, defaults):
-        """ Make a copy of a layer config and complete it with default values
+        """Make a copy of a layer config and complete it with default values
         for its block, if they are missing in the layer config.
         """
         conf = dict(config)
@@ -133,7 +134,7 @@ class BlockBuilder:
         return conf
 
     def _get_blocks(self, name=None):
-        """ Get the block class/function depending on the name. """
+        """Get the block class/function depending on the name."""
         if name is None:
             return self.all_blocks
         elif name.startswith("keras:"):
@@ -143,14 +144,17 @@ class BlockBuilder:
         else:
             raise NameError(
                 f"Unknown block type: {name}, must either start with "
-                f"'keras:', or be one of {list(self.all_blocks.keys())}")
+                f"'keras:', or be one of {list(self.all_blocks.keys())}"
+            )
 
     def _check_arguments(self, defaults):
-        """ Check if given defaults appear in at least one block. """
+        """Check if given defaults appear in at least one block."""
         if defaults is None:
             return
         # possible arguments for all blocks
-        psb_args = ["type", ]
+        psb_args = [
+            "type",
+        ]
         for block in self._get_blocks().values():
             args = list(inspect.signature(block.__init__).parameters.keys())
             for arg in args:
@@ -160,7 +164,8 @@ class BlockBuilder:
         for t_def in defaults.keys():
             if t_def not in psb_args:
                 warnings.warn(
-                    f"Unknown default argument: {t_def} (has to appear in a block)")
+                    f"Unknown default argument: {t_def} (has to appear in a block)"
+                )
 
 
 def get_input_block(input_shapes, batchsize=None, names=None):
@@ -189,19 +194,23 @@ def get_input_block(input_shapes, batchsize=None, names=None):
         input_names = list(input_shapes.keys())
     else:
         if not set(names) == set(input_shapes.keys()):
-            raise ValueError(f"Invalid input names: Expected {names} "
-                             f"got {list(input_shapes.keys())}")
+            raise ValueError(
+                f"Invalid input names: Expected {names} "
+                f"got {list(input_shapes.keys())}"
+            )
         input_names = names
 
     inputs = []
     for input_name in input_names:
-        inputs.append(layers.Input(
-            shape=input_shapes[input_name],
-            name=input_name,
-            dtype=ks.backend.floatx(),
-            batch_size=batchsize,
-            ragged=None in input_shapes[input_name],
-        ))
+        inputs.append(
+            layers.Input(
+                shape=input_shapes[input_name],
+                name=input_name,
+                dtype=ks.backend.floatx(),
+                batch_size=batchsize,
+                ragged=None in input_shapes[input_name],
+            )
+        )
 
     if len(inputs) == 1:
         return inputs[0]
@@ -211,8 +220,7 @@ def get_input_block(input_shapes, batchsize=None, names=None):
 
 class _attach_output_cat:
     # legacy
-    def __init__(self, categories, output_name,
-                 flatten=True):
+    def __init__(self, categories, output_name, flatten=True):
         self.categories = categories
         self.output_name = output_name
         self.flatten = flatten
