@@ -66,22 +66,26 @@ class ConvBlock:
         with specifying any strides value != 1.
 
     """
-    def __init__(self, conv_dim,
-                 filters,
-                 kernel_size=3,
-                 strides=1,
-                 padding="same",
-                 pool_type="max_pooling",
-                 pool_size=None,
-                 pool_padding="valid",
-                 dropout=None,
-                 sdropout=None,
-                 activation='relu',
-                 kernel_l2_reg=None,
-                 batchnorm=False,
-                 kernel_initializer="he_normal",
-                 time_distributed=False,
-                 dilation_rate=1):
+
+    def __init__(
+        self,
+        conv_dim,
+        filters,
+        kernel_size=3,
+        strides=1,
+        padding="same",
+        pool_type="max_pooling",
+        pool_size=None,
+        pool_padding="valid",
+        dropout=None,
+        sdropout=None,
+        activation="relu",
+        kernel_l2_reg=None,
+        batchnorm=False,
+        kernel_initializer="he_normal",
+        time_distributed=False,
+        dilation_rate=1,
+    ):
         self.conv_dim = conv_dim
         self.filters = filters
         self.kernel_size = kernel_size
@@ -101,8 +105,9 @@ class ConvBlock:
 
     def __call__(self, inputs):
         if self.dropout is not None and self.sdropout is not None:
-            raise ValueError("Can only use either dropout or spatial "
-                             "dropout, not both")
+            raise ValueError(
+                "Can only use either dropout or spatial " "dropout, not both"
+            )
 
         dim_layers = _get_dimensional_layers(self.conv_dim)
         convolution_nd = dim_layers["convolution"]
@@ -126,18 +131,22 @@ class ConvBlock:
             block_layers.append(dim_layers["zero_padding"](self.padding))
             padding = "valid"
 
-        block_layers.append(convolution_nd(
-            filters=self.filters,
-            kernel_size=self.kernel_size,
-            strides=self.strides,
-            padding=padding,
-            kernel_initializer=self.kernel_initializer,
-            use_bias=use_bias,
-            kernel_regularizer=kernel_reg,
-            dilation_rate=self.dilation_rate)
+        block_layers.append(
+            convolution_nd(
+                filters=self.filters,
+                kernel_size=self.kernel_size,
+                strides=self.strides,
+                padding=padding,
+                kernel_initializer=self.kernel_initializer,
+                use_bias=use_bias,
+                kernel_regularizer=kernel_reg,
+                dilation_rate=self.dilation_rate,
+            )
         )
         if self.batchnorm:
-            channel_axis = 1 if ks.backend.image_data_format() == "channels_first" else -1
+            channel_axis = (
+                1 if ks.backend.image_data_format() == "channels_first" else -1
+            )
             block_layers.append(layers.BatchNormalization(axis=channel_axis))
         if self.activation is not None:
             block_layers.append(layers.Activation(self.activation))
@@ -147,8 +156,9 @@ class ConvBlock:
             block_layers.append(pooling_nd())
         elif self.pool_size is not None:
             pooling_nd = dim_layers[self.pool_type]
-            block_layers.append(pooling_nd(
-                pool_size=self.pool_size, padding=self.pool_padding))
+            block_layers.append(
+                pooling_nd(pool_size=self.pool_size, padding=self.pool_padding)
+            )
 
         if self.dropout is not None:
             block_layers.append(layers.Dropout(self.dropout))
@@ -184,12 +194,16 @@ class DenseBlock:
         Adds a batch normalization layer.
 
     """
-    def __init__(self, units,
-                 dropout=None,
-                 activation='relu',
-                 kernel_l2_reg=None,
-                 batchnorm=False,
-                 kernel_initializer="he_normal"):
+
+    def __init__(
+        self,
+        units,
+        dropout=None,
+        activation="relu",
+        kernel_l2_reg=None,
+        batchnorm=False,
+        kernel_initializer="he_normal",
+    ):
         self.units = units
         self.dropout = dropout
         self.activation = activation
@@ -212,10 +226,13 @@ class DenseBlock:
             units=self.units,
             use_bias=use_bias,
             kernel_initializer=self.kernel_initializer,
-            kernel_regularizer=kernel_reg)(inputs)
+            kernel_regularizer=kernel_reg,
+        )(inputs)
 
         if self.batchnorm:
-            channel_axis = 1 if ks.backend.image_data_format() == "channels_first" else -1
+            channel_axis = (
+                1 if ks.backend.image_data_format() == "channels_first" else -1
+            )
             x = layers.BatchNormalization(axis=channel_axis)(x)
         if self.activation is not None:
             x = layers.Activation(self.activation)(x)
@@ -253,14 +270,18 @@ class ResnetBlock:
         If True, apply the TimeDistributed Wrapper around all layers.
 
     """
-    def __init__(self, conv_dim,
-                 filters,
-                 strides=1,
-                 kernel_size=3,
-                 activation='relu',
-                 batchnorm=False,
-                 kernel_initializer="he_normal",
-                 time_distributed=False):
+
+    def __init__(
+        self,
+        conv_dim,
+        filters,
+        strides=1,
+        kernel_size=3,
+        activation="relu",
+        batchnorm=False,
+        kernel_initializer="he_normal",
+        time_distributed=False,
+    ):
         self.conv_dim = conv_dim
         self.filters = filters
         self.kernel_size = kernel_size
@@ -271,32 +292,37 @@ class ResnetBlock:
         self.time_distributed = time_distributed
 
     def __call__(self, inputs):
-        x = ConvBlock(conv_dim=self.conv_dim,
-                      filters=self.filters,
-                      kernel_size=self.kernel_size,
-                      strides=self.strides,
-                      kernel_initializer=self.kernel_initializer,
-                      batchnorm=self.batchnorm,
-                      activation=self.activation,
-                      time_distributed=self.time_distributed)(inputs)
-        x = ConvBlock(conv_dim=self.conv_dim,
-                      filters=self.filters,
-                      kernel_size=self.kernel_size,
-                      kernel_initializer=self.kernel_initializer,
-                      batchnorm=self.batchnorm,
-                      activation=None,
-                      time_distributed=self.time_distributed)(x)
+        x = ConvBlock(
+            conv_dim=self.conv_dim,
+            filters=self.filters,
+            kernel_size=self.kernel_size,
+            strides=self.strides,
+            kernel_initializer=self.kernel_initializer,
+            batchnorm=self.batchnorm,
+            activation=self.activation,
+            time_distributed=self.time_distributed,
+        )(inputs)
+        x = ConvBlock(
+            conv_dim=self.conv_dim,
+            filters=self.filters,
+            kernel_size=self.kernel_size,
+            kernel_initializer=self.kernel_initializer,
+            batchnorm=self.batchnorm,
+            activation=None,
+            time_distributed=self.time_distributed,
+        )(x)
 
         if self.strides != 1:
-            shortcut = ConvBlock(conv_dim=self.conv_dim,
-                                 filters=self.filters,
-                                 kernel_size=1,
-                                 strides=self.strides,
-                                 kernel_initializer=self.kernel_initializer,
-                                 activation=None,
-                                 batchnorm=self.batchnorm,
-                                 time_distributed=self.time_distributed,
-                                 )(inputs)
+            shortcut = ConvBlock(
+                conv_dim=self.conv_dim,
+                filters=self.filters,
+                kernel_size=1,
+                strides=self.strides,
+                kernel_initializer=self.kernel_initializer,
+                activation=None,
+                batchnorm=self.batchnorm,
+                time_distributed=self.time_distributed,
+            )(inputs)
         else:
             shortcut = inputs
 
@@ -336,13 +362,17 @@ class ResnetBnetBlock:
         Initializer for the kernel weights.
 
     """
-    def __init__(self, conv_dim,
-                 filters,
-                 strides=1,
-                 kernel_size=3,
-                 activation='relu',
-                 batchnorm=False,
-                 kernel_initializer="he_normal"):
+
+    def __init__(
+        self,
+        conv_dim,
+        filters,
+        strides=1,
+        kernel_size=3,
+        activation="relu",
+        batchnorm=False,
+        kernel_initializer="he_normal",
+    ):
         self.conv_dim = conv_dim
         self.filters = filters
         self.kernel_size = kernel_size
@@ -354,35 +384,42 @@ class ResnetBnetBlock:
     def __call__(self, inputs):
         filters1, filters2, filters3 = self.filters
 
-        x = ConvBlock(conv_dim=self.conv_dim,
-                      filters=filters1,
-                      kernel_size=1,
-                      strides=self.strides,
-                      kernel_initializer=self.kernel_initializer,
-                      batchnorm=self.batchnorm,
-                      activation=self.activation)(inputs)
-        x = ConvBlock(conv_dim=self.conv_dim,
-                      filters=filters2,
-                      kernel_size=self.kernel_size,
-                      kernel_initializer=self.kernel_initializer,
-                      batchnorm=self.batchnorm,
-                      activation=self.activation)(x)
-        x = ConvBlock(conv_dim=self.conv_dim,
-                      filters=filters3,
-                      kernel_size=1,
-                      kernel_initializer=self.kernel_initializer,
-                      batchnorm=self.batchnorm,
-                      activation=None)(x)
+        x = ConvBlock(
+            conv_dim=self.conv_dim,
+            filters=filters1,
+            kernel_size=1,
+            strides=self.strides,
+            kernel_initializer=self.kernel_initializer,
+            batchnorm=self.batchnorm,
+            activation=self.activation,
+        )(inputs)
+        x = ConvBlock(
+            conv_dim=self.conv_dim,
+            filters=filters2,
+            kernel_size=self.kernel_size,
+            kernel_initializer=self.kernel_initializer,
+            batchnorm=self.batchnorm,
+            activation=self.activation,
+        )(x)
+        x = ConvBlock(
+            conv_dim=self.conv_dim,
+            filters=filters3,
+            kernel_size=1,
+            kernel_initializer=self.kernel_initializer,
+            batchnorm=self.batchnorm,
+            activation=None,
+        )(x)
 
         if self.strides != 1:
-            shortcut = ConvBlock(conv_dim=self.conv_dim,
-                                 filters=filters3,
-                                 kernel_size=1,
-                                 strides=self.strides,
-                                 kernel_initializer=self.kernel_initializer,
-                                 activation=None,
-                                 batchnorm=self.batchnorm,
-                                 )(inputs)
+            shortcut = ConvBlock(
+                conv_dim=self.conv_dim,
+                filters=filters3,
+                kernel_size=1,
+                strides=self.strides,
+                kernel_initializer=self.kernel_initializer,
+                activation=None,
+                batchnorm=self.batchnorm,
+            )(inputs)
         else:
             shortcut = inputs
 
@@ -425,16 +462,19 @@ class InceptionBlockV2:
         will be used, instead they will be skipped.
 
     """
-    def __init__(self,
-                 conv_dim,
-                 filters_1x1,
-                 filters_pool,
-                 filters_3x3,
-                 filters_3x3dbl,
-                 strides=1,
-                 activation="relu",
-                 batchnorm=False,
-                 dropout=None):
+
+    def __init__(
+        self,
+        conv_dim,
+        filters_1x1,
+        filters_pool,
+        filters_3x3,
+        filters_3x3dbl,
+        strides=1,
+        activation="relu",
+        batchnorm=False,
+        dropout=None,
+    ):
         self.filters_1x1 = filters_1x1  # 64
         self.filters_pool = filters_pool  # 64
         self.filters_3x3 = filters_3x3  # 48, 64
@@ -452,43 +492,54 @@ class InceptionBlockV2:
         # 1x1 convolution
         if self.filters_1x1 and self.strides == 1:
             branch1x1 = ConvBlock(
-                filters=self.filters_1x1, kernel_size=1,
-                strides=self.strides, **self.conv_options)(inputs)
+                filters=self.filters_1x1,
+                kernel_size=1,
+                strides=self.strides,
+                **self.conv_options,
+            )(inputs)
             branches.append(branch1x1)
 
         # pooling
         if self.filters_pool:
-            max_pooling_nd = _get_dimensional_layers(
-                self.conv_options["conv_dim"])["max_pooling"]
+            max_pooling_nd = _get_dimensional_layers(self.conv_options["conv_dim"])[
+                "max_pooling"
+            ]
             branch_pool = max_pooling_nd(
-                pool_size=3, strides=self.strides,  padding='same')(inputs)
+                pool_size=3, strides=self.strides, padding="same"
+            )(inputs)
             if self.strides == 1:
                 branch_pool = ConvBlock(
-                    filters=self.filters_pool, kernel_size=1,
-                    **self.conv_options)(branch_pool)
+                    filters=self.filters_pool, kernel_size=1, **self.conv_options
+                )(branch_pool)
             branches.append(branch_pool)
 
         # 3x3 convolution
         if self.filters_3x3:
             branch3x3 = ConvBlock(
-                filters=self.filters_3x3[0], kernel_size=1,
-                **self.conv_options)(inputs)
+                filters=self.filters_3x3[0], kernel_size=1, **self.conv_options
+            )(inputs)
             branch3x3 = ConvBlock(
-                filters=self.filters_3x3[1], kernel_size=3,
-                strides=self.strides, **self.conv_options)(branch3x3)
+                filters=self.filters_3x3[1],
+                kernel_size=3,
+                strides=self.strides,
+                **self.conv_options,
+            )(branch3x3)
             branches.append(branch3x3)
 
         # double 3x3 convolution
         if self.filters_3x3dbl:
             branch3x3dbl = ConvBlock(
-                filters=self.filters_3x3dbl[0], kernel_size=1,
-                **self.conv_options)(inputs)
+                filters=self.filters_3x3dbl[0], kernel_size=1, **self.conv_options
+            )(inputs)
             branch3x3dbl = ConvBlock(
-                filters=self.filters_3x3dbl[1], kernel_size=1,
-                **self.conv_options)(branch3x3dbl)
+                filters=self.filters_3x3dbl[1], kernel_size=1, **self.conv_options
+            )(branch3x3dbl)
             branch3x3dbl = ConvBlock(
-                filters=self.filters_3x3dbl[1], kernel_size=1,
-                strides=self.strides, **self.conv_options)(branch3x3dbl)
+                filters=self.filters_3x3dbl[1],
+                kernel_size=1,
+                strides=self.strides,
+                **self.conv_options,
+            )(branch3x3dbl)
             branches.append(branch3x3dbl)
 
         # concatenate all branches
@@ -521,15 +572,19 @@ class OutputReg:
         not None.
 
     """
-    def __init__(self, output_neurons,
-                 output_name,
-                 unit_list=None,
-                 transition='keras:Flatten',
-                 **kwargs):
+
+    def __init__(
+        self,
+        output_neurons,
+        output_name,
+        unit_list=None,
+        transition="keras:Flatten",
+        **kwargs,
+    ):
         self.output_neurons = output_neurons
         self.output_name = output_name
         if isinstance(unit_list, int):
-            unit_list = (unit_list, )
+            unit_list = (unit_list,)
         self.unit_list = unit_list
         self.transition = transition
         self.kwargs = kwargs
@@ -545,9 +600,8 @@ class OutputReg:
                 x = DenseBlock(units=units, **self.kwargs)(x)
 
         out = layers.Dense(
-            units=self.output_neurons,
-            activation=None,
-            name=self.output_name)(x)
+            units=self.output_neurons, activation=None, name=self.output_name
+        )(x)
 
         return out
 
@@ -570,17 +624,21 @@ class OutputRegNormal:
     See OutputReg for other parameters.
 
     """
-    def __init__(self, output_neurons,
-                 output_name,
-                 unit_list=None,
-                 mu_activation=None,
-                 sigma_activation="softplus",
-                 transition=None,
-                 **kwargs):
+
+    def __init__(
+        self,
+        output_neurons,
+        output_name,
+        unit_list=None,
+        mu_activation=None,
+        sigma_activation="softplus",
+        transition=None,
+        **kwargs,
+    ):
         self.output_neurons = output_neurons
         self.output_name = output_name
         if isinstance(unit_list, int):
-            unit_list = (unit_list, )
+            unit_list = (unit_list,)
         self.unit_list = unit_list
         self.mu_activation = mu_activation
         self.sigma_activation = sigma_activation
@@ -600,14 +658,17 @@ class OutputRegNormal:
         mu = layers.Dense(
             units=self.output_neurons,
             activation=self.mu_activation,
-            name=f"{self.output_name}_mu")(x)
+            name=f"{self.output_name}_mu",
+        )(x)
         sigma = layers.Dense(
             units=self.output_neurons,
             activation=self.sigma_activation,
-            name=f"{self.output_name}_sigma")(x)
+            name=f"{self.output_name}_sigma",
+        )(x)
 
         return layers.Concatenate(name=self.output_name, axis=-2)(
-            [tf.expand_dims(tsr, -2) for tsr in [mu, sigma]])
+            [tf.expand_dims(tsr, -2) for tsr in [mu, sigma]]
+        )
 
 
 @register
@@ -636,6 +697,7 @@ class OutputRegNormalSplit(OutputRegNormal):
     See OutputRegNormal for other parameters.
 
     """
+
     def __init__(self, *args, sigma_unit_list=None, **kwargs):
         super().__init__(*args, **kwargs)
         if sigma_unit_list is None:
@@ -655,7 +717,8 @@ class OutputRegNormalSplit(OutputRegNormal):
         mu = layers.Dense(
             units=self.output_neurons,
             activation=self.mu_activation,
-            name=self.output_name)(x)
+            name=self.output_name,
+        )(x)
 
         # Network for the errors of the labels
         x = ks.backend.stop_gradient(x_base)
@@ -665,11 +728,13 @@ class OutputRegNormalSplit(OutputRegNormal):
         sigma = layers.Dense(
             units=self.output_neurons,
             activation=self.sigma_activation,
-            name=f"{self.output_name}_sigma")(x)
+            name=f"{self.output_name}_sigma",
+        )(x)
 
         mu_stopped = ks.backend.stop_gradient(mu)
         err_output = layers.Concatenate(name=f"{self.output_name}_err", axis=-2)(
-            [tf.expand_dims(tsr, -2) for tsr in [mu_stopped, sigma]])
+            [tf.expand_dims(tsr, -2) for tsr in [mu_stopped, sigma]]
+        )
 
         return [mu, err_output]
 
@@ -698,11 +763,15 @@ class OutputCateg:
         not None.
 
     """
-    def __init__(self, categories,
-                 output_name,
-                 unit_list=None,
-                 transition='keras:Flatten',
-                 **kwargs):
+
+    def __init__(
+        self,
+        categories,
+        output_name,
+        unit_list=None,
+        transition="keras:Flatten",
+        **kwargs,
+    ):
         self.categories = categories
         self.output_name = output_name
         self.unit_list = unit_list
@@ -721,9 +790,10 @@ class OutputCateg:
 
         out = layers.Dense(
             units=self.categories,
-            activation='softmax',
-            kernel_initializer='he_normal',
-            name=self.output_name)(x)
+            activation="softmax",
+            kernel_initializer="he_normal",
+            name=self.output_name,
+        )(x)
 
         return out
 
@@ -747,6 +817,7 @@ class OutputRegErr:
         Keywords for the dense blocks.
 
     """
+
     # TODO deprecated, only here for historcal reasons
     def __init__(self, output_names, flatten=True, **kwargs):
         self.flatten = flatten
@@ -776,19 +847,19 @@ class OutputRegErr:
 
         for i, name in enumerate(self.output_names):
             output_label_error = layers.Dense(
-                units=1,
-                activation='linear',
-                name=name + '_err_temp')(x_err)
+                units=1, activation="linear", name=name + "_err_temp"
+            )(x_err)
             # Predicted label gets concatenated with its error (needed for loss function)
-            output_label_merged = layers.Concatenate(name=name + '_err')(
-                [outputs[i], output_label_error])
+            output_label_merged = layers.Concatenate(name=name + "_err")(
+                [outputs[i], output_label_error]
+            )
             outputs.append(output_label_merged)
         return outputs
 
 
 def _get_dimensional_layers(dim):
     if dim not in (1, 2, 3):
-        raise ValueError(f'Dimension must be 1, 2 or 3, not {dim}')
+        raise ValueError(f"Dimension must be 1, 2 or 3, not {dim}")
     dim_layers = {
         "convolution": {
             1: layers.Convolution1D,
