@@ -37,11 +37,15 @@ class Organizer:
         during training.
 
     """
-    def __init__(self, output_folder,
-                 list_file=None,
-                 config_file=None,
-                 tf_log_level=None,
-                 discover_tomls=True):
+
+    def __init__(
+        self,
+        output_folder,
+        list_file=None,
+        config_file=None,
+        tf_log_level=None,
+        discover_tomls=True,
+    ):
         """
         Set the attributes of the Configuration object.
 
@@ -75,7 +79,7 @@ class Organizer:
 
         """
         if tf_log_level is not None:
-            os.environ['TF_CPP_MIN_LOG_LEVEL'] = str(tf_log_level)
+            os.environ["TF_CPP_MIN_LOG_LEVEL"] = str(tf_log_level)
 
         if discover_tomls and list_file is None:
             list_file = orcanet.misc.find_file(output_folder, "list.toml")
@@ -150,7 +154,8 @@ class Organizer:
                 epochs_left = to_epoch
             else:
                 epochs_left = max(
-                    0, to_epoch - self.io.get_next_epoch(latest_epoch)[0] + 1)
+                    0, to_epoch - self.io.get_next_epoch(latest_epoch)[0] + 1
+                )
 
         trained_epochs = 0
         while epochs_left is None or trained_epochs < epochs_left:
@@ -210,7 +215,8 @@ class Organizer:
         if os.path.isfile(model_path):
             raise FileExistsError(
                 "Can not train model in epoch {} file {}, this model has "
-                "already been saved!".format(*next_epoch))
+                "already been saved!".format(*next_epoch)
+            )
 
         smry_logger = logging.SummaryLogger(self, model)
 
@@ -222,16 +228,20 @@ class Organizer:
         files_dict = self.io.get_file("train", next_epoch[1])
 
         line = "Training in epoch {} on file {}/{}".format(
-            next_epoch[0], next_epoch[1], self.io.get_no_of_files("train"))
+            next_epoch[0], next_epoch[1], self.io.get_no_of_files("train")
+        )
         self.io.print_log(line)
         self.io.print_log("-" * len(line))
-        self.io.print_log("Learning rate is at {}".format(
-            tf.keras.backend.get_value(model.optimizer.lr)))
-        self.io.print_log('Inputs and files:')
+        self.io.print_log(
+            "Learning rate is at {}".format(
+                tf.keras.backend.get_value(model.optimizer.lr)
+            )
+        )
+        self.io.print_log("Inputs and files:")
         for input_name, input_file in files_dict.items():
-            self.io.print_log("   {}: \t{}".format(input_name,
-                                                   os.path.basename(
-                                                       input_file)))
+            self.io.print_log(
+                "   {}: \t{}".format(input_name, os.path.basename(input_file))
+            )
 
         start_time = time.time()
         history = backend.train_model(self, model, next_epoch, batch_logger=True)
@@ -244,7 +254,7 @@ class Organizer:
             history_train=history,
         )
 
-        self.io.print_log('Training results:')
+        self.io.print_log("Training results:")
         for metric_name, loss in history.items():
             self.io.print_log(f"   {metric_name}: \t{loss}")
         self.io.print_log(f"Elapsed time: {timedelta(seconds=elapsed_s)}")
@@ -274,8 +284,10 @@ class Organizer:
         if latest_epoch is None:
             raise ValueError("Can not validate: No saved model found")
         if self.history.get_state()[-1]["is_validated"] is True:
-            raise ValueError("Can not validate in epoch {} file {}: "
-                             "Has already been validated".format(*latest_epoch))
+            raise ValueError(
+                "Can not validate in epoch {} file {}: "
+                "Has already been validated".format(*latest_epoch)
+            )
 
         if self._stored_model is None:
             model = self.load_saved_model(*latest_epoch)
@@ -293,7 +305,7 @@ class Organizer:
         history = backend.validate_model(self, model)
         elapsed_s = int(time.time() - start_time)
 
-        self.io.print_log('Validation results:')
+        self.io.print_log("Validation results:")
         for metric_name, loss in history.items():
             self.io.print_log(f"   {metric_name}: \t{loss}")
         self.io.print_log(f"Elapsed time: {timedelta(seconds=elapsed_s)}\n")
@@ -331,13 +343,7 @@ class Organizer:
             List to the paths of all the prediction files.
 
         """
-        if fileno is None and epoch is None:
-            epoch, fileno = self.history.get_best_epoch_fileno()
-            print(f"Automatically set epoch to epoch {epoch} file {fileno}.")
-        elif fileno is None or epoch is None:
-            raise ValueError(
-                "Either both or none of epoch and fileno must be None")
-
+        epoch, fileno = self._get_auto_epoch(epoch, fileno)
         if self._check_if_pred_already_done(epoch, fileno):
             print("Prediction has already been done.")
             pred_filepaths = self.io.get_pred_files_list(epoch, fileno)
@@ -350,10 +356,9 @@ class Organizer:
             self._set_up(model)
 
             start_time = time.time()
-            backend.make_model_prediction(
-                self, model, epoch, fileno, samples=samples)
+            backend.make_model_prediction(self, model, epoch, fileno, samples=samples)
             elapsed_s = int(time.time() - start_time)
-            print('Finished predicting on all validation files.')
+            print("Finished predicting on all validation files.")
             print("Elapsed time: {}\n".format(timedelta(seconds=elapsed_s)))
 
             pred_filepaths = self.io.get_pred_files_list(epoch, fileno)
@@ -373,9 +378,9 @@ class Organizer:
         Parameters
         ----------
         epoch : int, optional
-            Epoch of a model to load [default: lowest val loss].
+            Epoch of a model to load. Default: lowest val loss.
         fileno : int, optional
-            File number of a model to load [default: lowest val loss].
+            File number of a model to load. Default: lowest val loss.
         as_generator : bool
             If true, return a generator, which yields the output filename
             after the inference of each file.
@@ -394,14 +399,8 @@ class Organizer:
             return [filename for filename in gen]
 
     def _inference(self, epoch=None, fileno=None):
-        """ Get generator of doing inference, file by file. """
-        if fileno is None and epoch is None:
-            epoch, fileno = self.history.get_best_epoch_fileno()
-            print("Automatically set epoch to epoch {} file {}.".format(epoch, fileno))
-        elif fileno is None or epoch is None:
-            raise ValueError(
-                "Either both or none of epoch and fileno must be None")
-
+        """Get generator of doing inference, file by file."""
+        epoch, fileno = self._get_auto_epoch(epoch, fileno)
         if self._stored_model is None:
             model = self.load_saved_model(epoch, fileno, logging=False)
         else:
@@ -413,24 +412,82 @@ class Organizer:
             # output filename is based on name of file in first input
             first_filename = os.path.basename(list(files_dict.values())[0])
             output_filename = "model_epoch_{}_file_{}_on_{}".format(
-                epoch, fileno, first_filename)
+                epoch, fileno, first_filename
+            )
 
-            output_path = os.path.join(self.io.get_subfolder("inference"),
-                                       output_filename)
+            output_path = os.path.join(
+                self.io.get_subfolder("inference"), output_filename
+            )
             filenames.append(output_path)
             if os.path.exists(output_path):
-                warnings.warn("Warning: {} exists already, skipping "
-                              "file".format(output_filename))
+                print("File {} exists already, skipping...".format(output_filename))
                 continue
 
-            print(f'Working on file {first_filename}')
+            print(f"Working on file {first_filename}")
             start_time = time.time()
             backend.h5_inference(
-                self, model, files_dict, output_path, use_def_label=False)
+                self, model, files_dict, output_path, use_def_label=False
+            )
             elapsed_s = int(time.time() - start_time)
-            print(f'Finished on file {first_filename} in {elapsed_s/60} min')
+            print(f"Finished on file {first_filename} in {elapsed_s/60} min")
             yield output_path
 
+    def inference_on_file(
+        self, input_file, output_file=None, saved_model=None, epoch=None, fileno=None
+    ):
+        """
+        Save the model prediction for each sample of the given input file.
+
+        Useful for sharing a saved model, since the usual training folder
+        structure is not necessarily required.
+
+        Parameters
+        ---------
+        input_file : str or dict
+            Path to a DL file on which the inference should be done on.
+            Can also be a dict mapping input names to files.
+        output_file : str, optional
+            Save output to an h5 file with this name. Default: auto-generate
+            name and save in same directory as the input file.
+        saved_model : str, optional
+            Optional path to a saved model, which will be used instead
+            of loading the one with the given epoch/fileno.
+        epoch : int, optional
+            Epoch of a model to load from the directory. Only relevant if
+            saved_model is None. Default: lowest val loss.
+        fileno : int, optional
+            File number of a model to load from the directory. Only relevant
+            if saved_model is None. Default: lowest val loss.
+
+        Returns
+        -------
+        str
+            Name of the output file.
+
+        """
+        if saved_model is None:
+            epoch, fileno = self._get_auto_epoch(epoch, fileno)
+            model = self.load_saved_model(epoch, fileno, logging=False)
+        else:
+            model = self._load_model(saved_model)
+        self._set_up(model)
+
+        if isinstance(input_file, str):
+            input_file = {model.input_names[0]: input_file}
+        if output_file is None:
+            out_path, first_filename = os.path.split(list(input_file.values())[0])
+            output_file = os.path.join(out_path, "dl_pred_{}".format(first_filename))
+        start_time = time.time()
+        backend.h5_inference(
+            orga=self,
+            model=model,
+            files_dict=input_file,
+            output_path=output_file,
+        )
+        elapsed_s = int(time.time() - start_time)
+        print(f"Finished inference in {elapsed_s / 60} min")
+        return output_file
+
     def cleanup_models(self):
         """
         Delete all models except for the the most recent one (to continue
@@ -438,15 +495,21 @@ class Organizer:
 
         """
         all_epochs = self.io.get_all_epochs()
-        epochs_to_keep = {self.io.get_latest_epoch(), }
+        epochs_to_keep = {
+            self.io.get_latest_epoch(),
+        }
         try:
             for metric in self.history.get_metrics():
                 epochs_to_keep.add(
                     self.history.get_best_epoch_fileno(
-                        metric=f"val_{metric}", mini=True))
+                        metric=f"val_{metric}", mini=True
+                    )
+                )
                 epochs_to_keep.add(
                     self.history.get_best_epoch_fileno(
-                        metric=f"val_{metric}", mini=False))
+                        metric=f"val_{metric}", mini=False
+                    )
+                )
         except ValueError:
             # no best epoch exists
             pass
@@ -455,7 +518,8 @@ class Organizer:
             if epoch not in all_epochs:
                 warnings.warn(
                     f"ERROR: keeping_epoch {epoch} not in available epochs {all_epochs}, "
-                    f"skipping clean-up of models!")
+                    f"skipping clean-up of models!"
+                )
                 return
 
         print("\nClean-up saved models:")
@@ -481,7 +545,7 @@ class Organizer:
 
         """
         latest_pred_file_no = self.io.get_latest_prediction_file_no(epoch, fileno)
-        total_no_of_val_files = self.io.get_no_of_files('val')
+        total_no_of_val_files = self.io.get_no_of_files("val")
 
         if latest_pred_file_no is None:
             pred_done = False
@@ -492,6 +556,15 @@ class Organizer:
 
         return pred_done
 
+    def _get_auto_epoch(self, epoch, fileno):
+        """Automatically retrieve best epoch/fileno if they are none."""
+        if fileno is None and epoch is None:
+            epoch, fileno = self.history.get_best_epoch_fileno()
+            print("Automatically set epoch to epoch {} file {}.".format(epoch, fileno))
+        elif fileno is None or epoch is None:
+            raise ValueError("Either both or none of epoch and fileno must be None")
+        return epoch, fileno
+
     def get_xs_mean(self, logging=False):
         """
         Set and return the zero center image for each list input.
@@ -518,8 +591,9 @@ class Organizer:
         """
         if self.xs_mean is None:
             if self.cfg.zero_center_folder is None:
-                raise ValueError("Can not calculate zero center: "
-                                 "No zero center folder given")
+                raise ValueError(
+                    "Can not calculate zero center: " "No zero center folder given"
+                )
             self.xs_mean = load_zero_center_data(self, logging=logging)
         return self.xs_mean
 
@@ -548,14 +622,16 @@ class Organizer:
         return self._load_model(path_of_model)
 
     def _get_model(self, model, logging=False):
-        """ Load most recent saved model or use user model. """
+        """Load most recent saved model or use user model."""
         latest_epoch = self.io.get_latest_epoch()
 
         if latest_epoch is None:
             # new training, log info about model
             if model is None:
-                raise ValueError("You need to provide a compiled keras model "
-                                 "for the start of the training! (You gave None)")
+                raise ValueError(
+                    "You need to provide a compiled keras model "
+                    "for the start of the training! (You gave None)"
+                )
 
             elif isinstance(model, str):
                 # path to a saved model
@@ -569,7 +645,8 @@ class Organizer:
                 try:
                     plots_folder = self.io.get_subfolder("plots", create=True)
                     tf.keras.utils.plot_model(
-                        model, plots_folder + "/model_plot.png", show_shapes=True)
+                        model, plots_folder + "/model_plot.png", show_shapes=True
+                    )
                 except (ImportError, AttributeError) as e:
                     # TODO remove AttributeError once https://github.com/tensorflow/tensorflow/issues/38988 is fixed
                     warnings.warn("Can not plot model: " + str(e))
@@ -587,14 +664,15 @@ class Organizer:
         return model
 
     def _load_model(self, filepath):
-        """ Load from path, with custom objects and parallized. """
+        """Load from path, with custom objects and parallized."""
         with self.get_strategy().scope():
             model = tf.keras.models.load_model(
-                filepath, custom_objects=self.cfg.get_custom_objects())
+                filepath, custom_objects=self.cfg.get_custom_objects()
+            )
         return model
 
     def _save_as_json(self, model):
-        """ Save the architecture of a model as json to fixed path. """
+        """Save the architecture of a model as json to fixed path."""
         json_filename = "model_arch.json"
 
         json_string = model.to_json(indent=1)
@@ -603,17 +681,17 @@ class Organizer:
             f.write(json_string)
 
     def _set_up(self, model, logging=False):
-        """ Necessary setup for training, validating and predicting. """
-        if self.cfg.get_list_file() is None:
-            raise ValueError("No files specified. Need to load a toml "
-                             "list file with pathes to h5 files first.")
-
+        """Necessary setup for training, validating and predicting."""
         if self.cfg.label_modifier is None:
-            self._auto_label_modifier = lib.label_modifiers.ColumnLabels(model)
+            self._setup_auto_lmod(model)
 
         if self.cfg.zero_center_folder is not None:
             self.get_xs_mean(logging)
 
+    def _setup_auto_lmod(self, model):
+        """Set up the auto label modifier for the given model."""
+        self._auto_label_modifier = lib.label_modifiers.ColumnLabels(model)
+
     def val_is_due(self, epoch=None):
         """
         True if validation is due on given epoch according to schedule.
@@ -623,18 +701,18 @@ class Organizer:
         if epoch is None:
             epoch = self.io.get_latest_epoch()
         n_train_files = self.io.get_no_of_files("train")
-        val_sched = (epoch[1] == n_train_files) or \
-                    (self.cfg.validate_interval is not None and
-                     epoch[1] % self.cfg.validate_interval == 0)
+        val_sched = (epoch[1] == n_train_files) or (
+            self.cfg.validate_interval is not None
+            and epoch[1] % self.cfg.validate_interval == 0
+        )
         return val_sched
 
     def get_strategy(self):
-        """ Get the strategy for distributed training. """
+        """Get the strategy for distributed training."""
         if self._strategy is None:
-            if self.cfg.multi_gpu and len(
-                    tf.config.list_physical_devices('GPU')) > 1:
+            if self.cfg.multi_gpu and len(tf.config.list_physical_devices("GPU")) > 1:
                 self._strategy = tf.distribute.MirroredStrategy()
-                print(f'Number of GPUs: {self._strategy.num_replicas_in_sync}')
+                print(f"Number of GPUs: {self._strategy.num_replicas_in_sync}")
             else:
                 self._strategy = tf.distribute.get_strategy()
         return self._strategy
@@ -759,6 +837,7 @@ class Configuration(object):
         training, or loaded if they have been saved before.
 
     """
+
     # TODO add a clober script that properly deletes models + logfiles
     def __init__(self, output_folder, list_file=None, config_file=None, **kwargs):
         self.batchsize = 64
@@ -793,7 +872,7 @@ class Configuration(object):
         if output_folder[-1] == "/":
             self.output_folder = output_folder
         else:
-            self.output_folder = output_folder+"/"
+            self.output_folder = output_folder + "/"
 
         # Private attributes:
         self._files_dict = {
@@ -814,8 +893,7 @@ class Configuration(object):
             if hasattr(self, key):
                 setattr(self, key, val)
             else:
-                raise AttributeError(
-                    "Unknown attribute {}".format(key))
+                raise AttributeError("Unknown attribute {}".format(key))
 
         # deprecation warning TODO remove in the future
         if self.make_weight_plots:
@@ -832,8 +910,10 @@ class Configuration(object):
 
         """
         if self._list_file is not None:
-            raise ValueError("Can not load list file: Has already been loaded! "
-                             "({})".format(self._list_file))
+            raise ValueError(
+                "Can not load list file: Has already been loaded! "
+                "({})".format(self._list_file)
+            )
 
         file_content = toml.load(list_file)
 
@@ -864,13 +944,16 @@ class Configuration(object):
             if hasattr(self, key):
                 if key == "sample_modifier":
                     value = orcanet.misc.from_register(
-                        toml_entry=value, register=lib.sample_modifiers.smods)
+                        toml_entry=value, register=lib.sample_modifiers.smods
+                    )
                 elif key == "dataset_modifier":
                     value = orcanet.misc.from_register(
-                        toml_entry=value, register=lib.dataset_modifiers.dmods)
+                        toml_entry=value, register=lib.dataset_modifiers.dmods
+                    )
                 elif key == "label_modifier":
                     value = orcanet.misc.from_register(
-                        toml_entry=value, register=lib.label_modifiers.lmods)
+                        toml_entry=value, register=lib.label_modifiers.lmods
+                    )
                 setattr(self, key, value)
             else:
                 raise AttributeError(f"Unknown attribute {key} in config file")
@@ -911,7 +994,7 @@ class Configuration(object):
         return self._files_dict[which]
 
     def get_custom_objects(self):
-        """ Get user custom objects + orcanet internal ones. """
+        """Get user custom objects + orcanet internal ones."""
         orcanet_co = medgeconv.custom_objects
         orcanet_loss_functions = lib.losses.loss_functions
         return {**orcanet_co, **orcanet_loss_functions, **self.custom_objects}
@@ -970,7 +1053,6 @@ def _extract_filepaths(file_content, which):
             n_files.append(len(expanded_files))
 
     if n_files and n_files.count(n_files[0]) != len(n_files):
-        raise ValueError(
-            "Input with different number of {} in toml list".format(which))
+        raise ValueError("Input with different number of {} in toml list".format(which))
 
     return files
