@@ -6,20 +6,23 @@ import tensorflow.keras as ks
 
 
 class Hdf5BatchGenerator(ks.utils.Sequence):
-    def __init__(self, files_dict,
-                 batchsize=64,
-                 key_x_values="x",
-                 key_y_values="y",
-                 sample_modifier=None,
-                 label_modifier=None,
-                 fixed_batchsize=False,
-                 y_field_names=None,
-                 phase="training",
-                 xs_mean=None,
-                 f_size=None,
-                 keras_mode=True,
-                 shuffle=False,
-                 class_weights=None):
+    def __init__(
+        self,
+        files_dict,
+        batchsize=64,
+        key_x_values="x",
+        key_y_values="y",
+        sample_modifier=None,
+        label_modifier=None,
+        fixed_batchsize=False,
+        y_field_names=None,
+        phase="training",
+        xs_mean=None,
+        f_size=None,
+        keras_mode=True,
+        shuffle=False,
+        class_weights=None,
+    ):
         """
         Yields batches of input data from h5 files.
 
@@ -58,7 +61,8 @@ class Hdf5BatchGenerator(ks.utils.Sequence):
             before they are fed into the model.
         fixed_batchsize : bool
             The last batch in the file might be smaller then the batchsize.
-            Usually, this is no problem, but set to True to skip this batch.
+            Usually, this is no problem, but set to True to pad this batch to
+            given batchsize.
         xs_mean : ndarray or None
             Zero center image to be subtracted from data as preprocessing.
         f_size : int or None
@@ -92,7 +96,7 @@ class Hdf5BatchGenerator(ks.utils.Sequence):
 
         if y_field_names is not None:
             if isinstance(y_field_names, str):
-                y_field_names = (y_field_names, )
+                y_field_names = (y_field_names,)
             else:
                 y_field_names = tuple(y_field_names)
         self.y_field_names = y_field_names
@@ -106,14 +110,14 @@ class Hdf5BatchGenerator(ks.utils.Sequence):
         self._total_f_size = None
 
         # for keeping track of the readout speed
-        self._total_time = 0.
+        self._total_time = 0.0
         self._total_batches = 0
         self._file_meta = None
 
         self.open()
 
     def __len__(self):
-        """ Number of batches in the Sequence (includes queue). """
+        """Number of batches in the Sequence (includes queue)."""
         return len(self._sample_pos)
 
     def __getitem__(self, index):
@@ -180,14 +184,14 @@ class Hdf5BatchGenerator(ks.utils.Sequence):
         self._total_batches += 1
         if self.keras_mode:
             if info_blob.get("sample_weights"):
-                return xs, ys, info_blob["sample_weights"]
+                return info_blob["xs"], info_blob["ys"], info_blob["sample_weights"]
             else:
-                return xs, ys
+                return info_blob["xs"], info_blob["ys"]
         else:
             return info_blob
 
     def pad_to_size(self, info_blob):
-        """ Pad the batch to have a fixed batchsize. """
+        """Pad the batch to have a fixed batchsize."""
         org_batchsize = next(iter(info_blob["xs"].values())).shape[0]
         if org_batchsize == self.batchsize:
             return
@@ -199,14 +203,14 @@ class Hdf5BatchGenerator(ks.utils.Sequence):
                 info_blob["ys"][output_key] = _pad_to_size(y, self.batchsize)
 
     def open(self):
-        """ Open all files and prepare for read out. """
+        """Open all files and prepare for read out."""
         for input_key, file in self.files_dict.items():
-            self._files[input_key] = h5py.File(file, 'r')
+            self._files[input_key] = h5py.File(file, "r")
         self._store_file_length()
         self._store_batch_indices()
 
     def close(self):
-        """ Close all files again. """
+        """Close all files again."""
         for f in list(self._files.values()):
             f.close()
 
@@ -245,7 +249,8 @@ class Hdf5BatchGenerator(ks.utils.Sequence):
 
             if self.xs_mean is not None:
                 x_values[input_key] = np.subtract(
-                    x_values[input_key], self.xs_mean[input_key])
+                    x_values[input_key], self.xs_mean[input_key]
+                )
 
         return x_values
 
@@ -270,11 +275,17 @@ class Hdf5BatchGenerator(ks.utils.Sequence):
         try:
             slc = slice(start_index, start_index + self._batchsize)
             if self.y_field_names is not None and self.phase != "inference":
-                y_values = first_file[self.key_y_values][(slc,) + tuple(self.y_field_names,)]
+                y_values = first_file[self.key_y_values][
+                    (slc,)
+                    + tuple(
+                        self.y_field_names,
+                    )
+                ]
                 if len(self.y_field_names) == 1:
                     # result of slice is a ndarray; convert to structured
                     y_values = y_values.astype(
-                        np.dtype([(self.y_field_names[0], y_values.dtype)]))
+                        np.dtype([(self.y_field_names[0], y_values.dtype)])
+                    )
             else:
                 y_values = first_file[self.key_y_values][slc]
         except KeyError:
@@ -283,19 +294,18 @@ class Hdf5BatchGenerator(ks.utils.Sequence):
         return y_values
 
     def print_timestats(self, print_func=None):
-        """ Print stats about how long it took to read batches. """
+        """Print stats about how long it took to read batches."""
         if print_func is None:
             print_func = print
         print_func("Statistics of data readout:")
         print_func(f"\tTotal time:\t{self._total_time/60:.2f} min")
         if self._total_batches != 0:
             print_func(
-                f"\tPer batch:\t"
-                f"{1000 * self._total_time/self._total_batches:.5} ms"
+                f"\tPer batch:\t" f"{1000 * self._total_time/self._total_batches:.5} ms"
             )
 
     def get_file_meta(self):
-        """ Meta information about the files. Only read out once. """
+        """Meta information about the files. Only read out once."""
         if self._file_meta is None:
             self._file_meta = {}
             # sample and label dataset for each input
@@ -304,7 +314,9 @@ class Hdf5BatchGenerator(ks.utils.Sequence):
                 datasets[input_key] = {
                     "samples": file[self.key_x_values],
                     "samples_is_indexed": _get_indexed_dset_name(
-                        file, self.key_x_values) is not None,
+                        file, self.key_x_values
+                    )
+                    is not None,
                     "labels": file[self.key_y_values],
                 }
             self._file_meta["datasets"] = datasets
@@ -312,8 +324,8 @@ class Hdf5BatchGenerator(ks.utils.Sequence):
 
     @property
     def _size(self):
-        """ Size of the files that will be read in. Can be smaller than the actual
-        file size if defined by user. """
+        """Size of the files that will be read in. Can be smaller than the actual
+        file size if defined by user."""
         if self.f_size is None:
             return self._total_f_size
         else:
@@ -345,8 +357,10 @@ class Hdf5BatchGenerator(ks.utils.Sequence):
 
         if not lengths.count(lengths[0]) == len(lengths):
             self.close()
-            raise ValueError("All data files must have the same length! "
-                             "Given were:\n " + str(lengths))
+            raise ValueError(
+                "All data files must have the same length! "
+                "Given were:\n " + str(lengths)
+            )
 
         self._total_f_size = lengths[0]
 
@@ -371,7 +385,7 @@ class Hdf5BatchGenerator(ks.utils.Sequence):
 
 
 def _get_indexed_dset_name(file, dset):
-    """ If this is an indexed dataset, return the name of the indexed set. """
+    """If this is an indexed dataset, return the name of the indexed set."""
     dset_name_indexed = f"{dset}_indices"
     if file[dset].attrs.get("indexed") and dset_name_indexed in file:
         return dset_name_indexed
@@ -408,9 +422,16 @@ def _get_sample_weights(ys, class_weights):
     return sample_weights
 
 
-def get_h5_generator(orga, files_dict, f_size=None, zero_center=False,
-                     keras_mode=True, shuffle=False, use_def_label=True,
-                     phase="training"):
+def get_h5_generator(
+    orga,
+    files_dict,
+    f_size=None,
+    zero_center=False,
+    keras_mode=True,
+    shuffle=False,
+    use_def_label=True,
+    phase="training",
+):
     """
     Initialize the hdf5_batch_generator_base with the paramters in orga.cfg.
 
@@ -456,8 +477,9 @@ def get_h5_generator(orga, files_dict, f_size=None, zero_center=False,
     if orga.cfg.label_modifier is not None:
         label_modifier = orga.cfg.label_modifier
     elif use_def_label:
-        assert orga._auto_label_modifier is not None, \
-            "Auto label modifier has not been set up"
+        assert (
+            orga._auto_label_modifier is not None
+        ), "Auto label modifier has not been set up"
         label_modifier = orga._auto_label_modifier
     else:
         label_modifier = None
@@ -491,7 +513,8 @@ def get_h5_generator(orga, files_dict, f_size=None, zero_center=False,
 def make_dataset(gen):
     output_signature = tuple([{k: _get_spec(v) for k, v in d.items()} for d in gen[0]])
     return tf.data.Dataset.from_generator(
-        lambda: gen, output_signature=output_signature)
+        lambda: gen, output_signature=output_signature
+    )
 
 
 def _get_spec(x):
@@ -505,7 +528,7 @@ def _get_spec(x):
 
 
 def _pad_to_size(x, size):
-    """ Pad x to given size along axis 0 by repeating last element. """
+    """Pad x to given size along axis 0 by repeating last element."""
     length = x.shape[0]
     if length > size:
         raise ValueError(f"Can't pad x with shape {x.shape} to length {size}")
@@ -517,4 +540,4 @@ def _pad_to_size(x, size):
         else:
             f_conc = np.concatenate
 
-        return f_conc([x] + [x[-1:]] * length, axis=0)
+        return f_conc([x] + [x[-1:]] * (size - length), axis=0)
