@@ -10,7 +10,12 @@ import tensorflow.keras as ks
 import tensorflow.keras.layers as layers
 
 from orcanet.core import Organizer
-from orcanet.backend import train_model, validate_model, make_model_prediction, weighted_average
+from orcanet.backend import (
+    train_model,
+    validate_model,
+    make_model_prediction,
+    weighted_average,
+)
 import orcanet.lib as lib
 
 
@@ -28,7 +33,9 @@ class TestFunctions(TestCase):
         ]
 
         target = [
-            (0*1 + 3*3)/4, (1*1 + 4*3)/4, (2*1 + 5*3)/4,
+            (0 * 1 + 3 * 3) / 4,
+            (1 * 1 + 4 * 3) / 4,
+            (2 * 1 + 5 * 3) / 4,
         ]
         averaged_histories = weighted_average(histories, file_sizes)
 
@@ -44,9 +51,7 @@ class TestFunctions(TestCase):
             1,
         ]
 
-        target = [
-            0, 1, 2
-        ]
+        target = [0, 1, 2]
         averaged_histories = weighted_average(histories, file_sizes)
 
         self.assertSequenceEqual(averaged_histories, target)
@@ -54,8 +59,12 @@ class TestFunctions(TestCase):
     def test_weighted_average_one_metric(self):
         # metrics [A, ]
         histories = [
-            [0, ],  # file 1
-            [3, ],  # file 2
+            [
+                0,
+            ],  # file 1
+            [
+                3,
+            ],  # file 2
         ]
 
         file_sizes = [
@@ -64,7 +73,7 @@ class TestFunctions(TestCase):
         ]
 
         target = [
-            (0*1 + 3*3)/4,
+            (0 * 1 + 3 * 3) / 4,
         ]
         averaged_histories = weighted_average(histories, file_sizes)
 
@@ -73,7 +82,9 @@ class TestFunctions(TestCase):
     def test_weighted_average_one_metric_one_file(self):
         # metrics [A, ]
         histories = [
-            [1, ],  # file 1
+            [
+                1,
+            ],  # file 1
         ]
 
         file_sizes = [
@@ -98,9 +109,11 @@ class TestTrainValidatePredict(tf.test.TestCase):
         os.mkdir(cls.pred_dir)
 
         cls.pred_filepath = os.path.join(
-            cls.pred_dir,
-            'pred_model_epoch_1_file_3_on_listfilename_val_file_1.h5')
-        cls.file_sizes = [500, ]
+            cls.pred_dir, "pred_model_epoch_1_file_3_on_listfilename_val_file_1.h5"
+        )
+        cls.file_sizes = [
+            500,
+        ]
         # make some dummy data
         cls.inp_A_file = {
             "path": os.path.join(cls.temp_dir, "input_A_file.h5"),
@@ -138,7 +151,9 @@ class TestTrainValidatePredict(tf.test.TestCase):
 
         self.orga.io.get_local_files = MagicMock(return_value=self.filepaths)
         self.orga.io.get_file_sizes = MagicMock(return_value=self.file_sizes)
-        self.orga.cfg.get_list_file = MagicMock(return_value='/path/to/a/listfilename.toml')
+        self.orga.cfg.get_list_file = MagicMock(
+            return_value="/path/to/a/listfilename.toml"
+        )
         self.orga.io.get_next_pred_path = MagicMock(return_value=self.pred_filepath)
 
         self.model = build_dummy_model(self.input_shapes, self.output_shapes)
@@ -153,18 +168,21 @@ class TestTrainValidatePredict(tf.test.TestCase):
         epoch = (1, 1)
         batch_nos = []
         batch_print_callback = ks.callbacks.LambdaCallback(
-            on_batch_begin=lambda batch, logs: batch_nos.append(batch))
+            on_batch_begin=lambda batch, logs: batch_nos.append(batch)
+        )
         self.orga.cfg.callback_train = batch_print_callback
 
         history = train_model(self.orga, self.model, epoch, batch_logger=False)
         target = {  # TODO these sometimes change, so I set rtol to be high. But WHY???
-            'loss': 18.252519607543945,
-            'mc_A_loss': 9.647336959838867,
-            'mc_B_loss': 8.605181694030762,
+            "loss": 18.252519607543945,
+            "mc_A_loss": 9.647336959838867,
+            "mc_B_loss": 8.605181694030762,
         }
         print(history, target)
         assert_dict_arrays_equal(history, target, rtol=0.8)
-        self.assertSequenceEqual(batch_nos, list(range(int(self.file_sizes[0]/self.orga.cfg.batchsize))))
+        self.assertSequenceEqual(
+            batch_nos, list(range(int(self.file_sizes[0] / self.orga.cfg.batchsize)))
+        )
 
     def test_validate(self):
         history = validate_model(self.orga, self.model)
@@ -174,9 +192,9 @@ class TestTrainValidatePredict(tf.test.TestCase):
         # labels: 0 and 1
         # --> loss (18-0)^2 and (18-1)^2
         target = {
-            'loss': 18**2 + 17**2,
-            'mc_A_loss': 18**2,
-            'mc_B_loss': 17**2,
+            "loss": 18 ** 2 + 17 ** 2,
+            "mc_A_loss": 18 ** 2,
+            "mc_B_loss": 17 ** 2,
         }
         self.model.summary()
         self.assertDictEqual(history, target)
@@ -191,18 +209,20 @@ class TestTrainValidatePredict(tf.test.TestCase):
             make_model_prediction(self.orga, self.model, epoch, fileno)
 
             file_cntn = {}
-            with h5py.File(self.pred_filepath, 'r') as file:
+            with h5py.File(self.pred_filepath, "r") as file:
                 for key in file.keys():
                     file_cntn[key] = np.array(file[key])
         finally:
             os.remove(self.pred_filepath)
 
         target_datasets = [
-            'label_mc_A', 'label_mc_B', 'pred_mc_A', 'pred_mc_B', 'y_values'
-        ]
-        target_shapes = [
-            (500,), (500,), (500, 1), (500, 1), (500,)
+            "label_mc_A",
+            "label_mc_B",
+            "pred_mc_A",
+            "pred_mc_B",
+            "y_values",
         ]
+        target_shapes = [(500,), (500,), (500, 1), (500, 1), (500,)]
         target_contents = [
             np.zeros(target_shapes[0]),
             np.ones(target_shapes[1]),
@@ -213,7 +233,7 @@ class TestTrainValidatePredict(tf.test.TestCase):
         shapes_dict = dict(zip(target_datasets, target_shapes))
         contents_dict = dict(zip(target_datasets, target_contents))
 
-        target_mc_names = ('mc_A', 'mc_B')
+        target_mc_names = ("mc_A", "mc_B")
 
         datasets = list(file_cntn.keys())
         shapes = [file_cntn[key].shape for key in datasets]
@@ -241,7 +261,10 @@ def save_dummy_h5py(path, shape, size, mode="asc"):
     """
     xs = np.ones((size,) + shape)
 
-    dtypes = [('mc_A', '<f8'), ('mc_B', '<f8'), ]
+    dtypes = [
+        ("mc_A", "<f8"),
+        ("mc_B", "<f8"),
+    ]
     ys = np.ones((size, 2))
 
     if mode == "asc":
@@ -250,16 +273,16 @@ def save_dummy_h5py(path, shape, size, mode="asc"):
             ys[sample_no, ...] = sample_no + 0.5
 
     elif mode == "half":
-        ys[:, 0] = 0.
+        ys[:, 0] = 0.0
 
     else:
         raise AssertionError
 
     ys = ys.ravel().view(dtype=dtypes)
 
-    with h5py.File(path, 'w') as h5f:
-        h5f.create_dataset('x', data=xs, dtype='<f8')
-        h5f.create_dataset('y', data=ys, dtype=dtypes)
+    with h5py.File(path, "w") as h5f:
+        h5f.create_dataset("x", data=xs, dtype="<f8")
+        h5f.create_dataset("y", data=ys, dtype=dtypes)
     return xs, ys
 
 
@@ -272,8 +295,8 @@ def assert_dict_arrays_equal(a, b, rtol=1e-4):
 
 
 def assert_equal_struc_array(a, b):
-    """  np.testing.assert_array_equal does not work for arrays containing nans...
-     so test individual instead. """
+    """np.testing.assert_array_equal does not work for arrays containing nans...
+    so test individual instead."""
     np.testing.assert_array_equal(a.dtype, b.dtype)
     for name in a.dtype.names:
         np.testing.assert_almost_equal(a[name], b[name])
@@ -303,9 +326,11 @@ def build_dummy_model(input_shapes, output_shapes):
 
     outputs = []
     for name, shape in output_shapes.items():
-        outputs.append(layers.Dense(
-            shape, name=name, kernel_initializer="Ones",
-            bias_initializer="Zeros")(conc))
+        outputs.append(
+            layers.Dense(
+                shape, name=name, kernel_initializer="Ones", bias_initializer="Zeros"
+            )(conc)
+        )
 
     model = ks.models.Model(inputs, outputs)
     return model
