@@ -6,7 +6,6 @@ from orcanet.builder_util.builders import BlockBuilder
 
 
 class TestSequentialBuilder(tf.test.TestCase):
-
     def test_input_names_and_shapes_full_model(self):
         defaults = {"type": "conv_block", "conv_dim": 3}
         builder = BlockBuilder(defaults=defaults)
@@ -16,14 +15,28 @@ class TestSequentialBuilder(tf.test.TestCase):
         input_shapes = {input_name: input_shape}
 
         conv_layer_config = (
-            {"filters": 3, },
+            {
+                "filters": 3,
+            },
             {"filters": 3, "pool_size": (2, 2, 2)},
-            {"filters": 5, },
-            {"type": "OutputCateg", "output_name": "ts_output", "categories": 2, "transition": "keras:Flatten"}
+            {
+                "filters": 5,
+            },
+            {
+                "type": "OutputCateg",
+                "output_name": "ts_output",
+                "categories": 2,
+                "transition": "keras:Flatten",
+            },
         )
 
         model = builder.build(input_shapes, conv_layer_config)
-        self.assertEqual([input_name, ], model.input_names)
+        self.assertEqual(
+            [
+                input_name,
+            ],
+            model.input_names,
+        )
         self.assertEqual(input_shape, model.input_shape[1:])
 
     def test_attach_layer_conv(self):
@@ -37,7 +50,7 @@ class TestSequentialBuilder(tf.test.TestCase):
             "pool_size": 2,
             "dropout": 0.2,
             "batchnorm": True,
-            "kernel_l2_reg": 0.0001
+            "kernel_l2_reg": 0.0001,
         }
 
         builder = BlockBuilder(defaults)
@@ -56,7 +69,11 @@ class TestSequentialBuilder(tf.test.TestCase):
         self.assertEqual(model.output_shape[1:], (3, 3, 2))
 
     def test_attach_output_layers_regression_output_shape_and_names(self):
-        config = {"type": "OutputRegErr", "output_names": ['out_A', 'out_B'], "flatten": True}
+        config = {
+            "type": "OutputRegErr",
+            "output_names": ["out_A", "out_B"],
+            "flatten": True,
+        }
 
         inp = layers.Input((5, 1))
         builder = BlockBuilder()
@@ -64,10 +81,10 @@ class TestSequentialBuilder(tf.test.TestCase):
         model = Model(inp, x)
 
         target_output_shapes = {
-            'out_A': (1,),
-            'out_B': (1,),
-            'out_A_err': (2,),
-            'out_B_err': (2,),
+            "out_A": (1,),
+            "out_B": (1,),
+            "out_A_err": (2,),
+            "out_B_err": (2,),
         }
 
         output_shapes = {}
@@ -79,7 +96,12 @@ class TestSequentialBuilder(tf.test.TestCase):
     def test_attach_layer_dense(self):
         inp = layers.Input((3, 3, 1))
         defaults = {"type": "conv_block", "conv_dim": 2}
-        layer_config = {"type": "dense_block", "units": 5, "dropout": 0.2, "batchnorm": True}
+        layer_config = {
+            "type": "dense_block",
+            "units": 5,
+            "dropout": 0.2,
+            "batchnorm": True,
+        }
 
         builder = BlockBuilder(defaults)
         x = builder.attach_block(inp, layer_config)
