@@ -16,24 +16,30 @@ class TestIOHandler(TestCase):
     @classmethod
     def setUpClass(cls):
         # super(TestIOHandler, cls).setUpClass()
-        cls.temp_dir = os.path.join(os.path.dirname(__file__), ".temp",
-                                    "test_in_out")
-        cls.pred_dir = os.path.join(os.path.dirname(__file__), ".temp",
-                                    "test_in_out", "predictions")
+        cls.temp_dir = os.path.join(os.path.dirname(__file__), ".temp", "test_in_out")
+        cls.pred_dir = os.path.join(
+            os.path.dirname(__file__), ".temp", "test_in_out", "predictions"
+        )
         os.mkdir(cls.temp_dir)
         os.mkdir(cls.pred_dir)
 
         # make dummy pred files
-        Path(cls.pred_dir + '/pred_model_epoch_2_file_2_on_listname_val_file_1.h5').touch()
-        Path(cls.pred_dir + '/pred_model_epoch_2_file_2_on_listname_val_file_2.h5').touch()
+        Path(
+            cls.pred_dir + "/pred_model_epoch_2_file_2_on_listname_val_file_1.h5"
+        ).touch()
+        Path(
+            cls.pred_dir + "/pred_model_epoch_2_file_2_on_listname_val_file_2.h5"
+        ).touch()
 
-        cls.pred_filepaths = [cls.pred_dir + '/pred_model_epoch_2_file_2_on_listname_val_file_1.h5',
-                              cls.pred_dir + '/pred_model_epoch_2_file_2_on_listname_val_file_2.h5']
+        cls.pred_filepaths = [
+            cls.pred_dir + "/pred_model_epoch_2_file_2_on_listname_val_file_1.h5",
+            cls.pred_dir + "/pred_model_epoch_2_file_2_on_listname_val_file_2.h5",
+        ]
 
         cls.init_dir = os.getcwd()
         os.chdir(cls.temp_dir)
         # make some dummy data
-        cls.n_bins = {'input_A': (2, 3), 'input_B': (2, 3)}
+        cls.n_bins = {"input_A": (2, 3), "input_B": (2, 3)}
         cls.train_sizes = [30, 50]
         cls.val_sizes = [40, 60]
         cls.file_names = (
@@ -128,7 +134,7 @@ class TestIOHandler(TestCase):
         mocked_result = self.pred_dir
 
         def side_effect(key, create=False):
-            if key == 'predictions':
+            if key == "predictions":
                 return mocked_result
             else:
                 return original_get_subfolder(key, create)
@@ -166,12 +172,24 @@ class TestIOHandler(TestCase):
             scratch_dir = temp_temp_dir
 
             target_dirs_train = {
-                 "input_A": (scratch_dir + self.file_names[0], scratch_dir + self.file_names[1]),
-                 "input_B": (scratch_dir + self.file_names[2], scratch_dir + self.file_names[3]),
+                "input_A": (
+                    scratch_dir + self.file_names[0],
+                    scratch_dir + self.file_names[1],
+                ),
+                "input_B": (
+                    scratch_dir + self.file_names[2],
+                    scratch_dir + self.file_names[3],
+                ),
             }
             target_dirs_val = {
-                 "input_A": (scratch_dir + self.file_names[4], scratch_dir + self.file_names[5], ),
-                 "input_B": (scratch_dir + self.file_names[6], scratch_dir + self.file_names[7], ),
+                "input_A": (
+                    scratch_dir + self.file_names[4],
+                    scratch_dir + self.file_names[5],
+                ),
+                "input_B": (
+                    scratch_dir + self.file_names[6],
+                    scratch_dir + self.file_names[7],
+                ),
             }
 
             value = self.io.get_local_files("train")
@@ -210,10 +228,9 @@ class TestIOHandler(TestCase):
 
         def sample_modifier(info_blob):
             x_values = info_blob["x_values"]
-            return {'input_A': x_values["input_A"], 'input_B': x_values["input_B"]}
+            return {"input_A": x_values["input_A"], "input_B": x_values["input_B"]}
 
-        self.io.cfg.label_modifier = get_dummy_label_modifier(
-            output_shapes.keys())
+        self.io.cfg.label_modifier = get_dummy_label_modifier(output_shapes.keys())
         self.io.cfg.sample_modifier = sample_modifier
 
         model = build_dummy_model(input_shapes, output_shapes)
@@ -228,10 +245,9 @@ class TestIOHandler(TestCase):
 
         def sample_modifier(info_blob):
             x_values = info_blob["x_values"]
-            return {'input_A': x_values["input_A"]}
+            return {"input_A": x_values["input_A"]}
 
-        self.io.cfg.label_modifier = get_dummy_label_modifier(
-            output_shapes.keys())
+        self.io.cfg.label_modifier = get_dummy_label_modifier(output_shapes.keys())
         self.io.cfg.sample_modifier = sample_modifier
 
         model = build_dummy_model(input_shapes, output_shapes)
@@ -284,7 +300,10 @@ class TestIOHandler(TestCase):
 
         def sample_modifier(info_blob):
             x_values = info_blob["x_values"]
-            return {'input_A': x_values["input_A"], }
+            return {
+                "input_A": x_values["input_A"],
+            }
+
         self.io.cfg.sample_modifier = sample_modifier
 
         value = self.io.get_input_shapes()
@@ -297,23 +316,25 @@ class TestIOHandler(TestCase):
     def test_get_batch_xs(self):
         value = self.io.get_batch()
         target = {
-            "input_A": self.train_A_file_1_ctnt[0][:self.batchsize],
-            "input_B": self.train_B_file_1_ctnt[0][:self.batchsize],
+            "input_A": self.train_A_file_1_ctnt[0][: self.batchsize],
+            "input_B": self.train_B_file_1_ctnt[0][: self.batchsize],
         }
         assert_dict_arrays_equal(value["x_values"], target)
 
     def test_get_batch_ys(self):
         value = self.io.get_batch()
         target = {
-            "input_A": self.train_A_file_1_ctnt[1][:self.batchsize],
-            "input_B": self.train_B_file_1_ctnt[1][:self.batchsize],
+            "input_A": self.train_A_file_1_ctnt[1][: self.batchsize],
+            "input_B": self.train_B_file_1_ctnt[1][: self.batchsize],
         }
         assert_equal_struc_array(value["y_values"], target["input_A"])
 
     def test_get_all_epochs(self):
         epochs = self.io.get_all_epochs()
         target = [
-            (1, 1), (1, 2), (2, 1),
+            (1, 1),
+            (1, 2),
+            (2, 1),
         ]
         self.assertSequenceEqual(epochs, target)
 
@@ -354,17 +375,17 @@ class TestIOHandler(TestCase):
 
     def test_get_model_path(self):
         value = self.io.get_model_path(1, 1)
-        target = self.output_folder + '/saved_models/model_epoch_1_file_1.h5'
+        target = self.output_folder + "/saved_models/model_epoch_1_file_1.h5"
         self.assertEqual(value, target)
 
     def test_get_model_path_local(self):
         value = self.io.get_model_path(1, 1, local=True)
-        target = 'saved_models/model_epoch_1_file_1.h5'
+        target = "saved_models/model_epoch_1_file_1.h5"
         self.assertEqual(value, target)
 
     def test_get_model_path_latest(self):
         value = self.io.get_model_path(-1, -1)
-        target = self.output_folder + '/saved_models/model_epoch_2_file_1.h5'
+        target = self.output_folder + "/saved_models/model_epoch_2_file_1.h5"
         self.assertEqual(value, target)
 
     def test_get_model_path_latest_invalid(self):
@@ -406,22 +427,31 @@ class TestIOHandler(TestCase):
 
     def test_get_pred_path(self):
         value = self.io.get_pred_path(1, 2, 3)
-        target = self.io.get_subfolder("predictions") + '/pred_model_epoch_1_file_2_on_in_out_test_list_val_file_3.h5'
+        target = (
+            self.io.get_subfolder("predictions")
+            + "/pred_model_epoch_1_file_2_on_in_out_test_list_val_file_3.h5"
+        )
         self.assertEqual(value, target)
 
     def test_get_local_files_train(self):
         value = self.io.get_local_files("train")
         target = {
-            'input_A': ('input_A_train_1.h5', 'input_A_train_2.h5'),
-            'input_B': ('input_B_train_1.h5', 'input_B_train_2.h5'),
+            "input_A": ("input_A_train_1.h5", "input_A_train_2.h5"),
+            "input_B": ("input_B_train_1.h5", "input_B_train_2.h5"),
         }
         self.assertDictEqual(value, target)
 
     def test_get_local_files_val(self):
         value = self.io.get_local_files("val")
         target = {
-            'input_A': ('input_A_val_1.h5', 'input_A_val_2.h5',),
-            'input_B': ('input_B_val_1.h5', 'input_B_val_2.h5',)
+            "input_A": (
+                "input_A_val_1.h5",
+                "input_A_val_2.h5",
+            ),
+            "input_B": (
+                "input_B_val_1.h5",
+                "input_B_val_2.h5",
+            ),
         }
         self.assertDictEqual(value, target)
 
@@ -439,12 +469,12 @@ class TestIOHandler(TestCase):
         file_paths = self.io.yield_files("train")
         target = (
             {
-                'input_A': 'input_A_train_1.h5',
-                'input_B': 'input_B_train_1.h5',
+                "input_A": "input_A_train_1.h5",
+                "input_B": "input_B_train_1.h5",
             },
             {
-                'input_A': 'input_A_train_2.h5',
-                'input_B': 'input_B_train_2.h5',
+                "input_A": "input_A_train_2.h5",
+                "input_B": "input_B_train_2.h5",
             },
         )
         for i, value in enumerate(file_paths):
@@ -454,12 +484,12 @@ class TestIOHandler(TestCase):
         file_paths = self.io.yield_files("val")
         target = (
             {
-                'input_A': 'input_A_val_1.h5',
-                'input_B': 'input_B_val_1.h5',
+                "input_A": "input_A_val_1.h5",
+                "input_B": "input_B_val_1.h5",
             },
             {
-                'input_A': 'input_A_val_2.h5',
-                'input_B': 'input_B_val_2.h5',
+                "input_A": "input_A_val_2.h5",
+                "input_B": "input_B_val_2.h5",
             },
         )
         for i, value in enumerate(file_paths):
@@ -468,16 +498,16 @@ class TestIOHandler(TestCase):
     def test_get_file_train(self):
         value = self.io.get_file("train", 2)
         target = {
-                'input_A': 'input_A_train_2.h5',
-                'input_B': 'input_B_train_2.h5',
+            "input_A": "input_A_train_2.h5",
+            "input_B": "input_B_train_2.h5",
         }
         self.assertDictEqual(value, target)
 
     def test_get_file_val(self):
         value = self.io.get_file("val", 1)
         target = {
-                'input_A': 'input_A_val_1.h5',
-                'input_B': 'input_B_val_1.h5',
+            "input_A": "input_A_val_1.h5",
+            "input_B": "input_B_val_1.h5",
         }
         self.assertDictEqual(value, target)
 
@@ -487,9 +517,11 @@ class TestIOHandlerLR(TestCase):
     Test the learning rate method of the io handler. The csv part
     will generate files in the temp dir.
     """
+
     def setUp(self):
         self.temp_dir = os.path.join(
-            os.path.dirname(__file__), ".temp", "TestIOHandlerLR")
+            os.path.dirname(__file__), ".temp", "TestIOHandlerLR"
+        )
         os.makedirs(self.temp_dir)
 
         cfg = Configuration(self.temp_dir, None, None)
@@ -523,7 +555,7 @@ class TestIOHandlerLR(TestCase):
 
         rates_epoch_1 = [0.1, 0.08, 0.064]
         for fileno in range(no_train_files):
-            lr = self.get_learning_rate((1, fileno+1))
+            lr = self.get_learning_rate((1, fileno + 1))
             self.assertAlmostEqual(lr, rates_epoch_1[fileno])
 
         rates_epoch_2 = [0.0512, 0.04096, 0.032768]
@@ -533,7 +565,7 @@ class TestIOHandlerLR(TestCase):
 
     def test_get_learning_rate_function(self):
         def get_lr(epoch, filenos):
-            return epoch+filenos
+            return epoch + filenos
 
         user_lr = get_lr
         no_train_files = 3
@@ -543,7 +575,7 @@ class TestIOHandlerLR(TestCase):
 
         rates_epoch_1 = [2, 3, 4]
         for fileno in range(no_train_files):
-            lr = self.get_learning_rate((1, fileno+1))
+            lr = self.get_learning_rate((1, fileno + 1))
             self.assertAlmostEqual(lr, rates_epoch_1[fileno])
 
         rates_epoch_2 = [3, 4, 5]
@@ -568,11 +600,7 @@ class TestIOHandlerLR(TestCase):
         self.io.cfg.learning_rate = user_lr
         self.io.get_no_of_files = MagicMock(return_value=no_train_files)
 
-        csv_content = (
-            "1  2   0.1\n"
-            "1  3   0.2\n"
-            "2  2   0.3\n"
-        )
+        csv_content = "1  2   0.1\n" "1  3   0.2\n" "2  2   0.3\n"
 
         with open(os.path.join(self.temp_dir, "lr.csv"), "w") as f:
             f.write(csv_content)
@@ -590,8 +618,7 @@ class TestIOHandlerLR(TestCase):
             {"inp": (25, 33), "target": 0.3},
         ]
         for test in tests:
-            self.assertEqual(
-                self.get_learning_rate(test["inp"]), test["target"])
+            self.assertEqual(self.get_learning_rate(test["inp"]), test["target"])
 
     def test_get_learning_rate_read_csv_file_only_one_line(self):
         user_lr = "lr.csv"
@@ -600,9 +627,7 @@ class TestIOHandlerLR(TestCase):
         self.io.cfg.learning_rate = user_lr
         self.io.get_no_of_files = MagicMock(return_value=no_train_files)
 
-        csv_content = (
-            "0  1   2\n"
-        )
+        csv_content = "0  1   2\n"
 
         with open(os.path.join(self.temp_dir, "lr.csv"), "w") as f:
             f.write(csv_content)
@@ -611,8 +636,7 @@ class TestIOHandlerLR(TestCase):
             {"inp": (0, 1), "target": 2},
         ]
         for test in tests:
-            self.assertEqual(
-                self.get_learning_rate(test["inp"]), test["target"])
+            self.assertEqual(self.get_learning_rate(test["inp"]), test["target"])
 
     def test_get_learning_rate_read_csv_file_bad_format_too_short(self):
         user_lr = "lr.csv"
@@ -621,10 +645,7 @@ class TestIOHandlerLR(TestCase):
         self.io.cfg.learning_rate = user_lr
         self.io.get_no_of_files = MagicMock(return_value=no_train_files)
 
-        csv_content = (
-            "0  1\n"
-            "0  1\n"
-        )
+        csv_content = "0  1\n" "0  1\n"
 
         with open(os.path.join(self.temp_dir, "lr.csv"), "w") as f:
             f.write(csv_content)
@@ -639,10 +660,7 @@ class TestIOHandlerLR(TestCase):
         self.io.cfg.learning_rate = user_lr
         self.io.get_no_of_files = MagicMock(return_value=no_train_files)
 
-        csv_content = (
-            "0  1   2   4\n"
-            "0  1   2   3\n"
-        )
+        csv_content = "0  1   2   4\n" "0  1   2   3\n"
 
         with open(os.path.join(self.temp_dir, "lr.csv"), "w") as f:
             f.write(csv_content)
@@ -660,22 +678,25 @@ class TestFunctions(TestCase):
 
 
 def assert_equal_struc_array(a, b):
-    """  np.testing.assert_array_equal does not work for arrays containing nans...
-     so test individual instead. """
+    """np.testing.assert_array_equal does not work for arrays containing nans...
+    so test individual instead."""
     np.testing.assert_array_equal(a.dtype, b.dtype)
     for name in a.dtype.names:
         np.testing.assert_almost_equal(a[name], b[name])
 
 
-def save_dummy_h5py(path, shape, value_xs=1., value_ys=1., size=50):
+def save_dummy_h5py(path, shape, value_xs=1.0, value_ys=1.0, size=50):
     xs = np.ones((size,) + shape) * value_xs
 
-    dtypes = [('mc_A', '<f8'), ('mc_B', '<f8'), ]
-    ys = (np.ones((size, 2))*value_ys).ravel().view(dtype=dtypes)
+    dtypes = [
+        ("mc_A", "<f8"),
+        ("mc_B", "<f8"),
+    ]
+    ys = (np.ones((size, 2)) * value_ys).ravel().view(dtype=dtypes)
 
-    with h5py.File(path, 'w') as h5f:
-        h5f.create_dataset('x', data=xs, dtype='<f8')
-        h5f.create_dataset('y', data=ys, dtype=dtypes)
+    with h5py.File(path, "w") as h5f:
+        h5f.create_dataset("x", data=xs, dtype="<f8")
+        h5f.create_dataset("y", data=ys, dtype=dtypes)
 
     return xs, ys
 
@@ -715,6 +736,7 @@ def get_dummy_label_modifier(output_names):
         for output_name in output_names:
             y_true[output_name] = particle
         return y_true
+
     return label_modifier
 
 
@@ -722,4 +744,3 @@ def assert_dict_arrays_equal(a, b):
     for key, value in a.items():
         assert key in b
         np.testing.assert_array_almost_equal(a[key], b[key])
-
